@@ -7,13 +7,13 @@ describe Redwood::Util::Uri do
     it "builds uri from hash" do
       components = {:path => "/var/mail/foo", :scheme => "mbox"}
       uri = Redwood::Util::Uri.build(components)
-      uri.to_s.must_equal "mbox:/var/mail/foo"
+      assert_equal "mbox:/var/mail/foo", uri.to_s
     end
 
     it "expands ~ in path" do
       components = {:path => "~/foo", :scheme => "maildir"}
       uri = Redwood::Util::Uri.build(components)
-      uri.to_s.must_equal "maildir:#{ENV["HOME"]}/foo"
+      assert_equal "maildir:#{ENV["HOME"]}/foo", uri.to_s
     end
   end
 end
